#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 citeproc
version:              0.8.1.1
visibility:           public
id:                   citeproc-0.8.1.1-CjCMMHzaq2fLuPQuTnlmqh
key:                  citeproc-0.8.1.1-CjCMMHzaq2fLuPQuTnlmqh
license:              BSD-2-Clause
copyright:            2020 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Generates citations and bibliography from CSL styles.
description:
    citeproc parses CSL style files and uses them to
    generate a list of formatted citations and bibliography
    entries.  For more information about CSL, see
    <https://citationstyles.org/>.

category:             Text
abi:                  0bead3d5a9e415fcb4b7a7e046ef6386
exposed:              True
exposed-modules:
    Citeproc Citeproc.CaseTransform Citeproc.CslJson Citeproc.Eval
    Citeproc.Locale Citeproc.Pandoc Citeproc.Style Citeproc.Types

hidden-modules:       Citeproc.Element Citeproc.Data Citeproc.Unicode
import-dirs:          /usr/lib/ghc-9.6.6/site-local/citeproc-0.8.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/citeproc-0.8.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/citeproc-0.8.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-citeproc
hs-libraries:         HSciteproc-0.8.1.1-CjCMMHzaq2fLuPQuTnlmqh
depends:
    aeson-2.2.2.0-3wIqYzgVLxh1lGuh6CHfOQ
    attoparsec-0.14.4-FVjluS1LXeOBFikjeFFRQf base-4.18.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-5z8pg5dkh9iJJTZAXWxvrE
    containers-0.6.7 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    pandoc-types-1.23.1-4ixGGX9TbW393jf05DapBw
    safe-0.3.21-4vr9angs8ljJ6x4nxPJqmD
    scientific-0.3.8.1-9XG2AQ4sh0vL0ppOZ1hCCJ text-2.0.2
    text-icu-0.8.0.5-9InaflGDuOK9LIo97ZR8Dx transformers-0.6.1.0
    unicode-collation-0.1.3.6-7YouoAWxRM13wBbPDo4A8I
    uniplate-1.6.13-AbA9r1skBp66CRasTfGt8x
    vector-0.13.2.0-5aTe1V6fRGRBDLXlEcUVda
    xml-conduit-1.9.1.4-5NcvZLRcSVv2Y8J8pEe1P7

haddock-interfaces:   /usr/share/doc/haskell-citeproc/html/citeproc.haddock
haddock-html:         /usr/share/doc/haskell-citeproc/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

